@@ -253,7 +253,23 @@ return array(
 					'type' => 'hiddenString',
 					'default' => '',
 					'save_method' => 'storeSettingField'
-				)
+				),
+				'system_apply_specialsettings_default' => array(
+					'label' => $lng['serversettings']['apply_specialsettings_default'],
+					'settinggroup' => 'system',
+					'varname' => 'apply_specialsettings_default',
+					'type' => 'bool',
+					'default' => true,
+					'save_method' => 'storeSettingField'
+				),
+				'system_apply_phpconfigs_default' => array(
+					'label' => $lng['serversettings']['apply_phpconfigs_default'],
+					'settinggroup' => 'system',
+					'varname' => 'apply_phpconfigs_default',
+					'type' => 'bool',
+					'default' => true,
+					'save_method' => 'storeSettingField'
+				),
 			)
 		)
 	)
